syntropy.neural package
=======================

.. automodule:: syntropy.neural
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

syntropy.neural.multivariate\_mi module
---------------------------------------

.. automodule:: syntropy.neural.multivariate_mi
   :members:
   :show-inheritance:
   :undoc-members:

syntropy.neural.shannon module
------------------------------

.. automodule:: syntropy.neural.shannon
   :members:
   :show-inheritance:
   :undoc-members:

syntropy.neural.utils module
----------------------------

.. automodule:: syntropy.neural.utils
   :members:
   :show-inheritance:
   :undoc-members:
